@@ -58,6 +58,13 @@ namespace Lum {
     void Draw(int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static TextValue* Create(bool horizontalFlex=false, bool verticalFlex=false);
+    static TextValue* Create(Base::Model* model,
+                             bool horizontalFlex=false, bool verticalFlex=false);
+    static TextValue* Create(Base::Model* model,
+                             Alignment alignment,
+                             bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
