@@ -21,6 +21,8 @@
 
 #include <Lum/Base/L10N.h>
 
+#include <Lum/OS/Theme.h>
+
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Edit/Edit.h>
@@ -50,7 +52,7 @@ namespace Lum {
 
       panel=VPanel::Create(true,true);
       panel->SetMinHeight(Base::Size::workVRel,20);
-      panel->SetHeight(Base::Size::workVRel,60);
+      panel->SetHeight(Base::Size::workVRel,80);
 
       editContent=new Edit::Text();
       editContent->SetText(helpText);
@@ -70,8 +72,11 @@ namespace Lum {
       view->SetObject(edit);
 
       panel->Add(view);
-      panel->AddSpace();
-      panel->Add(ButtonRow::CreateClose(GetClosedAction(),true,false));
+
+      if (!OS::display->GetTheme()->ImplicitDefaultAction()) {
+        panel->AddSpace();
+        panel->Add(ButtonRow::CreateClose(GetClosedAction(),true,false));
+      }	
 
       SetMain(panel);
 
