@@ -1600,7 +1600,11 @@ namespace Lum {
   void String::InputHelper::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
     if (string!=NULL) {
-      if (dynamic_cast<Model::Action*>(model)!=NULL &&
+      if (model==backAction &&
+          backAction->IsFinished()) {
+        string->ActionBackspace();
+      }
+      else if (dynamic_cast<Model::Action*>(model)!=NULL &&
           dynamic_cast<Model::Action*>(model)->IsFinished()) {
         std::map<Model::ActionRef,std::wstring>::iterator iter=strings.find(dynamic_cast<Model::Action*>(model));
 
@@ -1608,9 +1612,6 @@ namespace Lum {
           string->ActionInsertString(iter->second);
         }
       }
-      else if (model==backAction) {
-        string->ActionBackspace();
-      }
     }
 
     Popup::Resync(model,msg);
